==> spicyR_1.2.0.tar.gz: spicyR/inst/doc/spicy.R <==
params <-
list(test = FALSE)

## ---- include = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
library(BiocStyle)

## ----warning=FALSE, message=FALSE---------------------------------------------
# load required packages
library(spicyR)
library(ggplot2)

## ---- eval = FALSE------------------------------------------------------------
#  if (!require("BiocManager"))
#      install.packages("BiocManager")
#  BiocManager::install("spicyR")

## ----message=FALSE------------------------------------------------------------
data("diabetesDataSub")
diabetesDataSub
cellSummary(diabetesDataSub)
imagePheno(diabetesDataSub)

## ----message=FALSE------------------------------------------------------------
spicyTestPair <- spicy(diabetesDataSub, 
                   condition = "condition", 
                   subject = "subject", 
                   from = "Tc", 
                   to = "Th")
spicyTestPair
topPairs(spicyTestPair)

## -----------------------------------------------------------------------------
data("spicyTest")

## ----eval=FALSE---------------------------------------------------------------
#  spicyTest <- spicy(diabetesDataSub,
#                     condition = "condition",
#                     subject = "subject")

## -----------------------------------------------------------------------------
spicyTest
topPairs(spicyTest)  

## -----------------------------------------------------------------------------
signifPlot(spicyTest, 
           breaks=c(-3, 3, 0.5),
           marksToPlot = c("alpha", "beta", "gamma", "delta", 
                           "B", "naiveTc", "Th", "Tc", "neutrophil", "macrophage"))

## -----------------------------------------------------------------------------
data("spicyTestBootstrap")

## ----eval=FALSE, warning=FALSE, message=FALSE---------------------------------
#  spicyTestBootstrap <- spicy(diabetesDataSub,
#                     condition = "condition",
#                     subject = "subject",
#                     from = "Tc",
#                     to = "Th",
#                     nsim = 1000)

## -----------------------------------------------------------------------------
spicyTestBootstrap

topPairs(spicyTestBootstrap)  

## -----------------------------------------------------------------------------
sessionInfo()

==> spicyR_1.10.0.tar.gz: spicyR/inst/doc/spicy.R <==
params <-
list(test = FALSE)

## ---- include = FALSE---------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  comment = "#>"
)
library(BiocStyle)

## ----warning=FALSE, message=FALSE---------------------------------------------
# load required packages
library(spicyR)
library(ggplot2)

## ---- eval = FALSE------------------------------------------------------------
#  if (!require("BiocManager"))
#      install.packages("BiocManager")
#  BiocManager::install("spicyR")

## -----------------------------------------------------------------------------
data("diabetesData")
diabetesData
cellSummary(diabetesData)
imagePheno(diabetesData)

## ----message=FALSE------------------------------------------------------------
spicyTestPair <- spicy(diabetesData, 
                       condition = "stage", 
                       subject = "case", 
                       from = "beta", 
                       to = "delta")

topPairs(spicyTestPair)

## ----eval=FALSE---------------------------------------------------------------
#  spicyTest <- spicy(diabetesData,
#                     condition = "stage",
#                     subject = "case")

## -----------------------------------------------------------------------------
data("spicyTest")

## -----------------------------------------------------------------------------
spicyTest
topPairs(spicyTest)  

## -----------------------------------------------------------------------------
signifPlot(spicyTest, 
           breaks=c(-3, 3, 1),
           marksToPlot = c("alpha", "beta", "gamma", "delta", 
                           "B", "naiveTc", "Th", "Tc", "neutrophil", "macrophage"))

## -----------------------------------------------------------------------------
sessionInfo()
